@@ -1180,7 +1180,7 @@ int get_radius(int id, double *_radius)
 {
     if(mpi_rank) {return 0;}
     unsigned int i = find(ident.begin(), ident.end(), id) - ident.begin();
-    //cerr << "hermite: get_radius: "; PRC(id); PRL(i); cerr << flush;
+    //cerr << "hermite0: get_radius: "; PRC(id); PRL(i); cerr << flush;
     if (i < ident.size())
       {
         *_radius = radius[i];
@@ -1505,7 +1505,7 @@ int get_gravity_at_point(
         rx = pos[i][0]-x;
         ry = pos[i][1]-y;
         rz = pos[i][2]-z;
-        r2 = (rx*rx+ry*ry+rz*rz + eps2);
+        r2 = (rx*rx+ry*ry+rz*rz + eps*eps);
         r = sqrt(r2);
         r3 = r2*r;
         F = mass[i]/r3;
